=======================================
 celery.backends.rpc
=======================================

.. contents::
    :local:
.. currentmodule:: celery.backends.rpc

.. automodule:: celery.backends.rpc
    :members:
    :undoc-members:
